# -*- coding: utf-8 -*-
from Products.Five.browser import BrowserView
from zope.component import getMultiAdapter
from course_view import CourseView
from jalon.content import contentMessageFactory as _

from DateTime import DateTime

from logging import getLogger
LOG = getLogger('[DepositBoxView]')


class DepositBoxView(CourseView):
    """Deposit Box View Class."""

    def __init__(self, context, request):
        """Deposit Box View init."""
        # LOG.info("----- Init -----")
        BrowserView.__init__(self, context, request)
        self.context = context
        self.request = request

    def isAnonymous(self):
        portal_state = getMultiAdapter((self.context, self.request),
                                       name=u'plone_portal_state')
        return portal_state.anonymous()

    def getBreadcrumbs(self):
        portal = self.context.portal_url.getPortalObject()
        parent = self.context.aq_parent
        return [{"title": _(u"Mes cours"),
                 "icon":  "fa fa-university",
                 "link":  "%s/mes_cours" % portal.absolute_url()},
                {"title": parent.Title(),
                 "icon":  "fa fa-book",
                 "link":  parent.absolute_url()},
                {"title": self.context.Title(),
                 "icon":  "fa fa-inbox",
                 "link":  self.context.absolute_url()}]

    def getDepositBoxView(self, user, mode_etudiant, tab, is_ajax):
        # LOG.info("----- getDepositBoxView (Start) -----")
        user_id = user.getId()
        my_view = {"is_anonymous": self.isAnonymous()}

        my_deposit_box = self.context
        instruction_text = my_deposit_box.Description()
        if instruction_text:
            my_view["instruction_class"] = "panel callout radius"
            my_view["instruction_text"] = instruction_text
        else:
            my_view["instruction_class"] = "panel radius"
            my_view["instruction_text"] = "Consigne non renseignée"

        my_view["deposit_box_id"] = my_deposit_box.getId()
        my_view["deposit_box_link"] = my_deposit_box.absolute_url()

        my_view["is_personnel"] = my_deposit_box.isPersonnel(user, mode_etudiant)
        my_view["mode_etudiant"] = "false" if (not mode_etudiant) and my_view["is_personnel"] else mode_etudiant

        if is_ajax or my_view["is_anonymous"]:
            my_view["came_from"] = "%s/login_form?came_from=%s" % (my_view["deposit_box_link"], my_deposit_box.jalon_quote(my_view["deposit_box_link"]))
            return my_view

        # LOG.info("***** DateAff : %s" % my_deposit_box.getDateAff())
        my_view["deposit_box_visibility"] = my_deposit_box.isAfficherElement(my_deposit_box.getDateAff(), my_deposit_box.getDateMasq())

        my_view["deposit_box_edit"] = []
        # LOG.info("***** deposit_box_visibility : %s" % my_view["deposit_box_visibility"])
        if my_view["deposit_box_visibility"]["val"]:
            my_view["deposit_box_edit"].append({"href": "%s/edit_course_item_visibility_form?item_id=%s&amp;tab=%s" % (my_view["deposit_box_link"], my_view["deposit_box_id"], tab),
                                                "icon": "fa-eye-slash",
                                                "text": "Masquer"})
        else:
            my_view["deposit_box_edit"].append({"href": "%s/edit_course_item_visibility_form?item_id=%s&amp;tab=%s" % (my_view["deposit_box_link"], my_view["deposit_box_id"], tab),
                                                "icon": "fa-eye",
                                                "text": "Afficher"})
        my_view["deposit_box_edit"].append({"href": "%s/edit_deposit_box_form?tab=%s" % (my_view["deposit_box_link"], tab),
                                            "icon": "fa-pencil",
                                            "text": "Titre"})

        my_view["deposit_box_deposit_date"] = my_deposit_box.getAffDate('dateDepot')
        my_view["is_authorized_deposit"] = my_deposit_box.isDepotActif()
        if my_view["is_authorized_deposit"] == 2:
            my_view["is_late"] = True
            my_view["class_limit_date"] = "callout"
        else:
            my_view["is_late"] = False
            my_view["class_limit_date"] = "warning"
            if my_view["is_authorized_deposit"] == 3:
                my_view["is_authorized_deposit"] = 0
                my_view["is_authorized_deposit_text"] = "Dans le profil évaluation par les pairs les \"dates limite de dépôts et d'évaluation\" sont obligatoires."

        my_view["grid_access"] = True if my_deposit_box.getAccesGrille(my_view["is_personnel"]) else False
        #my_view["grid_link"] = "%s/deposit_box_criteria_view?mode_etudiant=true" % my_view["deposit_box_link"]

        my_view["deposit_box_tabs"] = []

        my_view["is_documents_tab"] = True if tab == "documents" else False
        my_view["deposit_box_tabs"].append({"href":      "%s?tab=documents&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                            "css_class": " selected" if my_view["is_documents_tab"] else "",
                                            "icon":      "fa-upload",
                                            "text":      "Documents enseignants",
                                            "nb":        my_deposit_box.getNbSujets(my_view["is_personnel"])})
        if my_view["is_documents_tab"]:
            portal = my_deposit_box.portal_url.getPortalObject()
            deposit_box_path = my_deposit_box.getPhysicalPath()
            my_view["documents_add"] = self.getCourseItemAdderMenuList(my_view["deposit_box_link"], "/".join([deposit_box_path[-3], deposit_box_path[-2], deposit_box_path[-1]]), portal)["my_space"]
            my_view["documents_list"] = my_deposit_box.displayDocumentsList(my_view["is_personnel"], portal)

        my_view["is_deposit_tab"] = True if tab == "deposit" else False
        my_view["deposit_box_tabs"].append({"href":      "%s?tab=deposit&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                            "css_class": " selected" if my_view["is_deposit_tab"] else "",
                                            "icon":      "fa-download",
                                            "text":      "Mes dépôts" if not my_view["is_personnel"] and not my_deposit_box.getAccesDepots() else "Dépôts étudiants",
                                            "nb":        my_deposit_box.getNbDepots(my_view["is_personnel"], user_id)})
        my_view["deposit_tab_options"] = []
        if my_view["is_deposit_tab"]:
            my_view["deposit_tab_options_link"] = "%s/edit_deposit_tab_form" % my_view["deposit_box_link"]
            my_view["deposit_tab_options"] = [{"icon": "fa-toggle-on success" if my_deposit_box.getCorrectionIndividuelle() else "fa-toggle-off",
                                               "text": "Correction des dépôts"},
                                              {"icon": "fa-toggle-on success" if my_deposit_box.getNotificationCorrection() else "fa-toggle-off",
                                               "text": "Notification des corrections"},
                                              {"icon": "fa-toggle-on success" if my_deposit_box.getNotation() else "fa-toggle-off",
                                               "text": "Notation des dépôts"},
                                              {"icon": "fa-toggle-on success" if my_deposit_box.getNotificationNotation() else "fa-toggle-off",
                                               "text": "Notification des notations"},
                                              {"icon": "fa-toggle-on success" if my_deposit_box.getAccesDepots() else "fa-toggle-off",
                                               "text": "Visualisation des dépôts entre étudiants"}]

        deposit_box_profile = my_deposit_box.getProfile() or "standard"

        my_view["is_skills_tab"] = True if tab == "skills" else False
        if (my_view["is_personnel"] and deposit_box_profile == "competences") or my_deposit_box.getAfficherCompetences():
            my_view["deposit_box_tabs"].append({"href":      "%s?tab=skills&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                                "css_class": " selected" if my_view["is_skills_tab"] else "",
                                                "icon":      "fa-tasks",
                                                "text":      "Compétences",
                                                "nb":        my_deposit_box.getNbCompetences()})
        if my_view["is_skills_tab"]:
            my_view["skills_macro"] = "skills_teacher" if my_view["is_personnel"] else "skills_student"
            my_view["deposit_tab_options_link"] = "%s/edit_deposit_box_skills_options_form" % my_view["deposit_box_link"]
            my_view["deposit_tab_options"] = [{"icon": "fa-toggle-on success" if my_deposit_box.getAfficherCompetences() else "fa-toggle-off",
                                               "text": "Affichage de l'onglet \"Compétences\" aux étudiants"}]
            if my_deposit_box.getPermissionModifierCompetence(my_view["is_personnel"], user_id):
                my_view["deposit_tab_options"].append({"icon": "fa-toggle-on success" if my_deposit_box.getModifierCompetences() else "fa-toggle-off",
                                                       "text": "Restriction de la gestion des compétences"})

        my_view["deposit_peer_options"] = []
        my_view["is_peers_tab"] = True if tab == "peers" else False
        if deposit_box_profile == "pairs":
            my_view["deposit_box_tabs"].append({"href":      "%s?tab=peers&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                                "css_class": " selected" if my_view["is_peers_tab"] else "",
                                                "icon":      "fa-users",
                                                "text":      "Dépôts à évaluer" if not my_view["is_personnel"] else "Par les pairs",
                                                "nb":        my_deposit_box.getPeerLength(my_view["is_personnel"], user_id)})
        if my_view["is_peers_tab"]:
            my_view["accessEvaluation"] = not my_view["is_personnel"] and my_deposit_box.getAccesEvaluation()
            my_view["accessSelfEvaluation"] = not my_view["is_personnel"] and my_deposit_box.getAutoriserAutoEvaluation()
            my_view["deposit_tab_options_link"] = ""
            my_view["deposit_peer_options"] = [{"link":  "%s/edit_peers_correction_number_form" % my_view["deposit_box_link"],
                                                "class": "panel callout radius",
                                                "icon":  "fa fa-users fa-fw no-pad",
                                                "text":  "Évaluation(s) par étudiants",
                                                "value": my_deposit_box.getNombreCorrection()},
                                               {"link":  "%s/edit_peers_adjustment_form" % my_view["deposit_box_link"],
                                                "class": "panel callout radius",
                                                "icon":  "fa fa-balance-scale fa-fw no-pad",
                                                "text":  "Ajustement",
                                                "value": my_deposit_box.getDisplayPenality()},
                                               {"link":  "%s/edit_peers_grid_access_form" % my_view["deposit_box_link"],
                                                "class": "panel callout radius",
                                                "icon":  "fa fa-th fa-fw no-pad",
                                                "text":  "Accès à la grille d'évaluation",
                                                "value": my_deposit_box.getDisplayGridAccess()},
                                               {"link":  "%s/edit_peers_self_evaluation_form" % my_view["deposit_box_link"],
                                                "class": "panel callout radius",
                                                "icon":  "fa fa-user fa-fw no-pad",
                                                "text":  "Autoriser l'auto-évaluation",
                                                "value": my_deposit_box.getDisplayAuthorizeSelfEvaluation()}]
            my_view["is_depot_actif"] = True
            my_view["is_correction_actif"] = True
            if my_view["is_authorized_deposit"] != 3:
                now = DateTime(DateTime()).strftime("%Y/%m/%d %H:%M")
                date_depot = DateTime(my_deposit_box.getDateDepot()).strftime("%Y/%m/%d %H:%M")
                if now >= date_depot:
                    my_view["is_depot_actif"] = False
                date_correction = DateTime(my_deposit_box.getDateCorrection()).strftime("%Y/%m/%d %H:%M")
                if now >= date_correction:
                    my_view["is_correction_actif"] = False

            if my_view["accessSelfEvaluation"]:
                self_evaluation_note = my_deposit_box.portal_jalon_bdd.getSelfEvaluationNote(my_view["deposit_box_id"], user_id).first()
                if self_evaluation_note:
                    my_view["self_evalution_button"] = "fa fa-trophy"
                    my_view["self_evalution_link"] = "%s/deposit_box_evaluation_view" % my_view["deposit_box_link"]
                    my_view["self_evalution_name"] = "Consulter mon auto-évaluation"
                else:
                    my_view["self_evalution_button"] = "fa fa-user"
                    my_view["self_evalution_link"] = "%s/evaluate_deposit_file_form?deposit_id=auto" % my_view["deposit_box_link"]
                    my_view["self_evalution_name"] = "Réaliser mon auto-évaluation"

        my_view["deposit_box_profile"] = {"href":  "%s/edit_deposit_box_profile_form?tab=%s" % (my_view["deposit_box_link"], tab),
                                          "icon": "fa-pencil",
                                          "text": "Profil"}
        my_view["deposit_box_profile_text"] = my_deposit_box.getDisplayProfile()
        my_view["deposit_box_date"] = {"href":  "%s/edit_deposit_box_date_form?tab=%s" % (my_view["deposit_box_link"], tab),
                                       "icon": "fa-pencil",
                                       "text": "Modifier"}
        my_view["is_peer_profile"] = False
        if my_deposit_box.getProfile() == "pairs":
            my_view["is_peer_profile"] = True
            my_view["deposit_box_correction_date"] = {"link":  "%s/edit_peers_correction_date_form?tab=%s" % (my_view["deposit_box_link"], tab),
                                                      "class": "panel warning radius",
                                                      "icon":  "fa fa-pencil fa-fw no-pad",
                                                      "text":  "Date limite d'évaluation",
                                                      "value": my_deposit_box.getAffDate('dateCorrection')}

        my_view["deposit_box_instruction"] = {"href":  "%s/edit_deposit_box_instruction_form?tab=%s" % (my_view["deposit_box_link"], tab),
                                              "icon":  "fa-pencil",
                                              "text":  "Modifier"}

        my_view["is_personnel_or_deposit_box_visible"] = True if my_view["is_personnel"] or my_view["deposit_box_visibility"]['val'] != 0 else False
        # LOG.info("***** is_personnel : %s" % my_view["is_personnel"])
        # LOG.info("***** affElement : %s" % my_view["deposit_box_visibility"]['val'])
        my_view["is_student_and_deposit_box_hidden"] = True if (not my_view["is_personnel"]) and my_view["deposit_box_visibility"]['val'] == 0 else False
        my_view["is_display_mod"] = my_deposit_box.isAuteurs(user.getId())
        # LOG.info("----- getDepositBoxView (End) -----")
        return my_view



# -*- coding: utf-8 -*-
from Products.Five.browser import BrowserView
from zope.component import getMultiAdapter

from jalon.content import contentMessageFactory as _

from logging import getLogger
LOG = getLogger('[DepositBoxEvaluationView]')


class DepositBoxEvaluationView(BrowserView):
    """Class pour le first_page
    """

    def __init__(self, context, request):
        # LOG.info("----- Init -----")
        BrowserView.__init__(self, context, request)
        self.context = context
        self.request = request

    def isAnonymous(self):
        portal_state = getMultiAdapter((self.context, self.request),
                                       name=u'plone_portal_state')
        return portal_state.anonymous()

    def getBreadcrumbs(self):
        portal = self.context.portal_url.getPortalObject()
        parent = self.context.aq_parent
        deposit_box_link = self.context.absolute_url()
        return [{"title": _(u"Mes cours"),
                 "icon":  "fa fa-university",
                 "link":  "%s/mes_cours" % portal.absolute_url()},
                {"title": parent.Title(),
                 "icon":  "fa fa-book",
                 "link":  parent.absolute_url()},
                {"title": self.context.Title(),
                 "icon":  "fa fa-inbox",
                 "link":  "%s?tab=peers" % deposit_box_link},
                {"title": "Mon évaluation",
                 "icon":  "fa fa-trophy",
                 "link":  "%s/deposit_box_evaluation_view" % deposit_box_link}]

    def getStudentEvaluationView(self, student_id):
        # LOG.info("----- getStudentEvaluationView (Start) -----")
        deposit_box = self.context
        deposit_box_id = deposit_box.getId()
        student_name = deposit_box.getIndividu(student_id, "dict")["fullname"]
        #student_infos = deposit_box.getIndividu(student_id, "dict")
        #if student_infos:
        #    student_name = "%s %s" % (student_infos["nom"], student_infos["prenom"])
        #else:
        #    student_name = student_id

        my_view = {"is_anonymous":          self.isAnonymous(),
                   "student_name":          student_name,
                   "acces_evaluations":     deposit_box.getAccesEvaluation(),
                   "acces_self_evaluation": deposit_box.getAutoriserAutoEvaluation(),
                   "has_self_evaluation":   False,
                   "has_evaluation":        True}
        jalon_bdd = self.context.portal_jalon_bdd

        if my_view["acces_self_evaluation"]:
            self_evaluation_note = jalon_bdd.getSelfEvaluationNote(deposit_box_id, student_id).first()
            if self_evaluation_note:
                my_view["has_self_evaluation"] = True
                my_view["self_evaluation_note"] = self_evaluation_note[0]

                my_view["self_evaluation_dict"] = {}
                for line in jalon_bdd.getSelfEvaluate(deposit_box_id, student_id).all():
                    my_view["self_evaluation_dict"][line[0]] = {"criteria_note":    line[1],
                                                                "criteria_comment": line[-1]}

        if my_view["acces_evaluations"]:
            peer_evaluation_list = jalon_bdd.getPeerEvaluation(deposit_box_id, student_id)
            my_view["peer_evaluation"] = {}
            for ligne in peer_evaluation_list.all():
                # LOG.info("***** ligne : %s" % str(ligne))
                try:
                    my_view["peer_evaluation"][ligne[0]].append({"corrected_stu": ligne[1], "criteria_note": ligne[2], "criteria_comment": ligne[-1]})
                except:
                    my_view["peer_evaluation"][ligne[0]] = [{"corrected_stu": ligne[1], "criteria_note": ligne[2], "criteria_comment": ligne[-1]}]
            # LOG.info("***** peer_evaluation : %s" % str(my_view["peer_evaluation"]))

            my_view["peer_average"] = {}
            average_list = jalon_bdd.getPeerAverage(deposit_box_id, student_id)
            for ligne in average_list.all():
                criteria_state = True if ligne[2] != 1 else False
                my_view["peer_average"][ligne[0]] = {"criteria_state": criteria_state, "criteria_note": ligne[1], "criteria_note_t": ligne[-2], "criteria_comment": ligne[-1]}
            # LOG.info("***** peer_average : %s" % str(my_view["peer_average"]))
            try:
                my_view["evaluation_note"] = jalon_bdd.getEvaluationNoteByDeposiSTU(deposit_box_id, student_id).first()[0]
            except:
                my_view["has_evaluation"] = False
                my_view["evaluation_note"] = "Non noté"
        my_view["criteria_dict"] = deposit_box.getCriteriaDict()
        my_view["criteria_order"] = deposit_box.getCriteriaOrder()
        my_view["comment_dict"] = {"0": "Aucun",
                                   "1": "Optionnel",
                                   "2": "Obligatoire"}
        # LOG.info("----- getStudentEvaluationView (End) -----")

        return my_view

    def getDetailsVerificationEvaluations(self, user, mode_etudiant, tab):
        # LOG.info("----- getDetailsVerificationEvaluations -----")
        deposit_box = self.context
        deposit_box_id = deposit_box.getId()

        my_view = {}
        my_view["is_personnel"] = deposit_box.isPersonnel(user, mode_etudiant)
        my_view["mode_etudiant"] = "false" if (not mode_etudiant) and my_view["is_personnel"] else mode_etudiant

        portal = deposit_box.portal_url.getPortalObject()
        parent = deposit_box.aq_parent
        my_view["deposit_box_link"] = deposit_box.absolute_url()
        jalon_bdd = deposit_box.portal_jalon_bdd
        evaluations_notes = jalon_bdd.getCountEvaluationsNotes(deposit_box_id).first()[0]
        evaluations_notes_uncheck = jalon_bdd.getCountVerifEvaluationsNotes(deposit_box_id).first()[0]
        evaluations_notes_check = evaluations_notes - evaluations_notes_uncheck

        if not tab:
            if evaluations_notes_uncheck == 0:
                tab = "2"
            else:
                tab = "1"

        my_view["breadcrumbs"] = [{"title": _(u"Mes cours"),
                                   "icon":  "fa fa-university",
                                   "link":  "%s/mes_cours" % portal.absolute_url()},
                                  {"title": parent.Title(),
                                   "icon":  "fa fa-book",
                                   "link":  parent.absolute_url()},
                                  {"title": deposit_box.Title(),
                                   "icon":  "fa fa-inbox",
                                   "link":  "%s?tab=peers" % my_view["deposit_box_link"]},
                                  {"title": "Évaluations à vérifier",
                                   "icon":  "fa fa-list",
                                   "link":  "%s/deposit_box_details_evaluations_view?tab=%s&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], tab, my_view["mode_etudiant"])}]

        my_view["peers_average_dict"] = {}
        my_view["criteria_dict"] = deposit_box.getCriteriaDict()
        my_view["criteria_order"] = deposit_box.getCriteriaOrder()

        my_view["details_evaluations_tabs"] = []
        my_view["is_uncheck_tab"] = True if tab == "1" else False
        my_view["details_evaluations_tabs"].append({"href":      "%s/deposit_box_details_evaluations_view?tab=1&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                                    "css_class": " selected" if my_view["is_uncheck_tab"] else "",
                                                    "icon":      "fa-times",
                                                    "text":      "Évaluations à vérifier",
                                                    "nb":        evaluations_notes_uncheck})
        if my_view["is_uncheck_tab"]:
            check = 2
            my_view["title"] = "Évaluations à vérifier"

        my_view["is_check_tab"] = True if tab == "2" else False
        my_view["details_evaluations_tabs"].append({"href":      "%s/deposit_box_details_evaluations_view?tab=2&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                                    "css_class": " selected" if my_view["is_check_tab"] else "",
                                                    "icon":      "fa-check-square-o",
                                                    "text":      "Évaluations correctes",
                                                    "nb":        evaluations_notes_check})
        if my_view["is_check_tab"]:
            check = 1
            my_view["title"] = "Évaluations correctes"

        my_view["is_all_tab"] = True if tab == "3" else False
        my_view["details_evaluations_tabs"].append({"href":      "%s/deposit_box_details_evaluations_view?tab=3&amp;mode_etudiant=%s" % (my_view["deposit_box_link"], mode_etudiant),
                                                    "css_class": " selected" if my_view["is_all_tab"] else "",
                                                    "icon":      "fa-list-ul",
                                                    "text":      "Toutes les évaluations",
                                                    "nb":        evaluations_notes})
        if my_view["is_all_tab"]:
            check = None
            my_view["title"] = "Toutes les évaluations"
            """
            my_view["peers_list"] = deposit_box.getPeersOrder()

            for criteria_note in jalon_bdd.getInfoCriteriaNoteByDepositStu(deposit_box_id).all():
                if not criteria_note[0] in my_view["peers_average_dict"]:
                    my_view["peers_average_dict"][criteria_note[0]] = {criteria_note[1]: {"criteria_note":  criteria_note[2],
                                                                                          "criteria_error": True if criteria_note[3] in [2, 3] else False}}
                else:
                    my_view["peers_average_dict"][criteria_note[0]][criteria_note[1]] = {"criteria_note":  criteria_note[2],
                                                                                         "criteria_error": True if criteria_note[3] in [2, 3] else False}

            for evaluation_note in jalon_bdd.getInfoEvaluationNoteByDepositStu(deposit_box_id).all():
                my_view["peers_average_dict"][evaluation_note[0]]["evaluation_note"] = evaluation_note[1]
                my_view["peers_average_dict"][evaluation_note[0]]["evaluation_error"] = evaluation_note[2]
            """

        evaluations = self.getEvaluations(jalon_bdd, deposit_box, deposit_box_id, check)
        my_view["peers_list"] = evaluations["peers_list"]
        my_view["peers_average_dict"] = evaluations["peers_average_dict"]
        return my_view

    def getEvaluations(self, jalon_bdd, deposit_box, deposit_box_id, check=None):
        peers_list = []
        peers_average_dict = {}
        infos_peers = deposit_box.getInfosPeersDict()

        for evaluation_note in jalon_bdd.getInfoEvaluationNoteByDepositStu(deposit_box_id, check).all():
            peers_average_dict[evaluation_note[0]] = {"evaluation_note":  evaluation_note[1],
                                                      "evaluation_error": evaluation_note[2]}
            peers_list.append({"id":  evaluation_note[0],
                               "nom": infos_peers[evaluation_note[0]]})

        for criteria_note in jalon_bdd.getInfoCriteriaNoteByDepositStu(deposit_box_id).all():
            if criteria_note[0] in peers_average_dict:
                peers_average_dict[criteria_note[0]][criteria_note[1]] = {"criteria_note":  criteria_note[2],
                                                                          "criteria_error": True if criteria_note[3] in [2, 3] else False}

        peers_list.sort(lambda x, y: cmp(x["nom"], y["nom"]))
        return {"peers_list":         peers_list,
                "peers_average_dict": peers_average_dict}



## Controller Python Script "typefichier_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=imageName
##title=
##

"""
    À enrichir éventuellement en éditant les types mime de Zope,
    et en ajoutant des entrées dans le tableau ci-après :

        clé     = nom du fichier image retourné dans le "brain"
        valeur  = icône FA associée

"""

fileType = imageName.split('.')

return {
    'application':  'fa-file',
    'audio':        'fa-file-audio-o',
    'avi':          'fa-file-video-o',
    'doc':          'fa-file-word-o',
    'image':        'fa-file-image-o',
    'midi':         'fa-file-audio-o',
    'pdf':          'fa-file-pdf-o',
    'png':          'fa-file-image-o',
    'ppt':          'fa-file-powerpoint-o',
    'ps':           'fa-file-image-o',
    'quicktime':    'fa-file-video-o',
    'rpm':          'fa-file-archive-o',
    'sxc':          'fa-file-excel-o',
    'tar':          'fa-file-archive-o',
    'text':         'fa-file-text-o',
    'tgz':          'fa-file-archive-o',
    'txt':          'fa-file-text-o',
    'video':        'fa-file-video-o',
    'wav':          'fa-file-audio-o',
    'xls':          'fa-file-excel-o',
    'zip':          'fa-file-archive-o',
    }.get( fileType[ 0 ], 'fa-file-o' )



# -*- coding: utf-8 -*-
## Controller Python Script "dupliquer_cours"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=Dupliquer un cours
##

from Products.CMFPlone import PloneMessageFactory as _

request = context.REQUEST
user_id = request.form["user_id"]

if "course_id" in request.form:
    course_id = request.form["course_id"]
    course_user_folder = context.getCourseUserFolder(user_id)
    course_object = getattr(course_user_folder, course_id)
    redirection = "%s?tab=%s" % (context.absolute_url(), request.form["tab"])
else:
    course_object = context
    redirection = context.absolute_url()

if course_object.isAuteurs(user_id):
    # On purge les boites de dépot
    course_object.purgerDepots()

    message = u"Le cours « <strong>%s</strong> » a bien été purgé." % course_object.getShortText(course_object.Title()).decode("utf-8")
    context.plone_utils.addPortalMessage(_(message), "success")

    # Puis on purge les activités WIMS
    resultatWIMS = course_object.purgerActivitesWims()

    if resultatWIMS:
        compteur = 0
        for userWims in resultatWIMS:
            if resultatWIMS[userWims]["cleaned"] is not None:
                compteur = compteur + resultatWIMS[userWims]["cleaned"]
            else:
                message = u"Une erreur est survenue lors de la purge des activités WIMS"
                context.plone_utils.addPortalMessage(_(message), "error")

        message = u"<strong>%s</strong> note(s) Wims supprimée(s)" % (compteur)
        context.plone_utils.addPortalMessage(_(message), "info")
else:
    message = _(u"Vous tentez d'accéder à une page qui ne vous appartient pas. Une suspicion de fraude vous concernant a été envoyée à l'administrateur du site.")
    context.plone_utils.addPortalMessage(_(message), "alert")
    context.envoyerMailErreur({"objet":   "Unauthorized access to purger_activites",
                               "message": "<p>Suspicion de fraude de l'utilisateur <strong>%s</strong></p><div>%s</div>" % (user_id, request)})

request.RESPONSE.redirect(redirection)



# -*- coding: utf-8 -*-

from zope.interface import Interface


class IJalonContent(Interface):
    ''' Interface for the JalonContent type
    '''


class IJalonFolder(Interface):
    ''' Interface for the JalonFolder type
    '''


class IJalonCours(Interface):
    ''' Interface for the JalonCours type
    '''


class IJalonCoursWims(Interface):
    ''' Interface for the JalonCoursWims type
    '''


class IJalonActivity(Interface):
    ''' Interface for the JalonActivity type
    '''


class IJalonBoiteDepot(Interface):
    ''' Interface for the JalonBoiteDepot type
    '''


class IJalonRessourceExterne(Interface):
    ''' Interface for the JalonRessourceExtern type
    '''


class IJalonTermeGlossaire(Interface):
    ''' Interface for the JalonTermeGlossaire type
    '''


class IJalonConnect(Interface):
    ''' Interface for the JalonConnect type
    '''


class IJalonExerciceWims(Interface):
    ''' Interface for the JalonExerciceWims type
    '''


class IJalonFile(Interface):
    ''' Interface for the JalonFile type
    '''


class IJalonForum(Interface):
    ''' Interface for the JalonForum type
    '''


class IJalonAnnonce(Interface):
    ''' Interface for the JalonAnnonce type
    '''



## Controller Python Script "rennomer_categorie_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=Renommer une categorie
##

request = context.REQUEST
form = request.form

context.renommerCategorie(form["clef"], form["title"])
context.REQUEST.RESPONSE.redirect("%s/gestion_mes_cours?gestion=gestion_categorie" % context.absolute_url())


##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=userid=None, entry=None
##title=
##

# context = context

portal = context.portal_url.getPortalObject()
serveur = portal.getProperty("title")
portal.mes_etudiants.envoyerMailErreur({"objet"   : "%s : Erreur [%s]" % (serveur, userid),
                                        "entry"   : entry})

return "envoie"


# -*- coding: utf-8 -*-
"""##Controller Python Script "create_wims_exercice_script"."""
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

# PloneMessageFactory permet d'utiliser le systeme i18n
from Products.CMFPlone import PloneMessageFactory as _

""" Script de creation des exercices WIMS de Mon Espace."""
""" Cheminement normal : my_wims_exercices_view.pt -> javascript:setRevealFormNewPage()
                            -> create_wims_exercice_form.cpt -> validate_my_space
                                -> create_wims_exercice_script -> javascript:setRevealFormNewPage() -> $page_url """
# Le contexte est un jalonfolder
#context = context
REQUEST = context.REQUEST
form = REQUEST.form

wims_exercice_model = form["modele"]

# attention : possible "faille" de securité : si un utilisateur envoi un autre member_id, il créé l'exercice dans un autre espace.
user_id = context.supprimerCaractereSpeciaux(form["member_id"])
wims_exercice_folder = context.getMySubSpaceFolder(user_id, "Wims")

# Create a new JalonExerciceWIMS
object_id = wims_exercice_folder.invokeFactory(type_name='JalonExerciceWims', id="%s-%s-%s" % (wims_exercice_model, user_id, DateTime().strftime("%Y%m%d%H%M%S")))
wims_exercice_object = getattr(wims_exercice_folder, object_id)

page_url = context.absolute_url()

title = form["title"].decode("utf-8")
success_message       = _(u"L'exercice « %s » a été ajouté. Construisez-le ci-dessous." % title)
unknown_model_message = _(u"Une erreur est survenue sur votre exercice « %s » (modèle introuvable ?). Merci de contacter l'administrateur de cette plateforme, en fournissant tous les détails possibles permettant de reproduire cette erreur svp." % title)
unavailable_message   = _(u"Le serveur WIMS est actuellement injoignable. Merci de réessayer ultérieurement.")

# Cas des Modules externes
if wims_exercice_model == "externe":
    permalink = REQUEST.get("permalink", '')
    wims_exercice_object.setProperties({"Title":     form["title"],
                                        "Modele":    wims_exercice_model,
                                        "Permalink": permalink})

# Cas classique : on ajoute l'exercice côté WIMS
else:
    rep = wims_exercice_object.addExoWims(idobj=object_id, title=form["title"], author_id=user_id, modele=wims_exercice_model)
    # print rep
    if not("status" in rep):
        # La creation a planté (Cause : modele inconnu ?)
        wims_exercice_folder.manage_delObjects(ids=[object_id])
        context.plone_utils.addPortalMessage(unknown_model_message, 'error')
    else:
        # L'appel à WIMS s'est bien passé, on applique les modifications à l'objet Jalon
        if rep["status"] == "OK":
            wims_exercice_object.setProperties({"Title":  form["title"],
                                                "Modele": wims_exercice_model})
            context.plone_utils.addPortalMessage(success_message, 'success')
            page_url = "%s/edit_wims_exercice_form" % wims_exercice_object.absolute_url()
        else:
            # La creation a planté coté WIMS, on supprime l'objet que l'on vient de créer sur Jalon.
            wims_exercice_folder.manage_delObjects(ids=[object_id])
            context.plone_utils.addPortalMessage(unavailable_message, 'error')

return page_url



# -*- coding: utf-8 -*-
from zope.component import getUtility

from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.CMFCore.utils import getToolByName

from jalon.content import contentMessageFactory as _
from jalon.content.content import jalon_encode

from datetime import datetime
from DateTime import DateTime

import smtplib

from email import message_from_string
from email.MIMEMultipart import MIMEMultipart
from email.MIMEText import MIMEText
from email.Header import Header
import email.Utils

from urlparse import urlparse
import urllib
import urllib2
import locale
import json
import re
import copy

# Messages de debug :
# from logging import getLogger
# LOG = getLogger('[jalon_utils]')


def authUser(context, quser=None, qclass=None, request=None, session_keep=False):
    u"""AuthUser WIMS : permet d'authentifier "quser" dans une classe wims "qclass".

    # request représente les parametres envoyés à la page (GET/POST)
    # session_keep permet de définir si on réutilise une eventuelle session wims existante ou pas.

    """
    # LOG.info("----- authUser -----")
    remote_addr = None
    url_connexion = context.wims("getAttribut", "url_connexion")
    # error_dict = {"status": "ERROR"}
    if request:
        # HTTP_X_REAL_IP n'existe que si la configuration de Nginx fournit bien ce
        # parametre à Zope.
        remote_addr = request.get('HTTP_X_REAL_IP', None)
        if not remote_addr:
            remote_addr = request['REMOTE_ADDR']

        if session_keep is True:
            # Si session_keep=True et qu'une session wims était déjà ouverte, on la conserve.
            # Attention : ici il faudrait vérifier sur WIMS que la session ouverte
            # était bien celle de l'utilisateur courant.
            wims_session = request.get('wims_session', None)
            if wims_session:
                return {'wims_session': wims_session,
                        'status':       'OK',
                        'home_url':     "%s?session=%s" % (url_connexion, wims_session)}
    dico = {"qclass": qclass, "quser": quser, "code": quser,
            "option": "lightpopup", "data1": remote_addr}
    rep = context.wims("authUser", dico)
    try:
        rep = json.loads(rep)
        # rep = context.wims("verifierRetourWims", {"rep": rep, "fonction": "jalon.content/jalon_utils.py/authUser", "message": "1ere identification de l'utilisateur %s." % quser, "requete": dico})
    except ValueError, e:
            rep = '{"status":"ERROR","exception_raised":"%s","message":"%s"}' % (
                string_for_json(rep), e)
            rep = json.loads(rep)

    if rep["status"] == "ERROR":
        # On prépare un éventuel message d'erreur à renvoyer
        message = _(
            u"Le serveur WIMS est actuellement injoignable. Merci de réessayer ultérieurement svp...")
        mess_type = "error"
        if quser != 'supervisor':

            if "in an exam session started on another IP" in rep["message"]:
                message = _(u"Vous tentez de vous connecter à un examen commencé sur une machine différente.<br/>\n\
                Veuillez retourner sur la machine où vous avez commencé votre examen pour pouvoir le finir.")
                # mess_title = "Impossible d'accéder à cet examen."
                context.plone_utils.addPortalMessage(message, type=mess_type)
                return None

            dico_ETU = getIndividu(quser, "dict")

            """
            dico_ETU = getIndividu(quser, type="dict")
            if dico_ETU:
                firstname = dico_ETU["prenom"]
                lastname = dico_ETU["nom"]
            else:
                fullname = getDisplayName(quser, request)
                firstname, lastname = fullname.split(" ", 1)
            """

            # Sur une premiere erreur, on considere que l'utilisateur est inexistant.
            # on tente alors de le créer.
            user = context.wims("creerUser", {"quser": quser, "qclass": qclass,
                                              "firstname": dico_ETU["prenom"],
                                              "lastname":  dico_ETU["nom"]})
            if user["status"] == "ERROR":
                # Si la creation de l'utilisateur plante, alors WIMS doit être indisponible.
                context.plone_utils.addPortalMessage(message, type=mess_type)
                return None
            # dico = {"qclass": qclass, "quser": quser, "code": quser, "option": "lightpopup", "data1": remote_addr}
            rep = context.wims("authUser", dico)
            rep = context.wims("verifierRetourWims", {"rep": rep, "fonction": "jalon_utils/authUser",
                               "message": "impossible d'authentifier l'utilisateur %s. (Sur 2e essai)" % quser, "requete": dico})
        else:
            # L'authentification du supervisor a planté.
            # => WIMS doit être indisponible. (Ou WIMS a refusé la connexion.)
            # Cas possible : supervisor is in an exam session started on another IP
            context.plone_utils.addPortalMessage(message, type=mess_type)
            context.wims("verifierRetourWims", {"rep": rep, "fonction": "jalon_utils/authUser",
                         "message": "impossible d'authentifier le supervisor", "requete": dico})
            # LOG.info("**** authUser | Impossible d'authentifier le supervisor : %s" % rep)
            return None
    rep["url_connexion"] = url_connexion
    # LOG.info("**** authUser | rep = %s" % rep)
    return rep


def string_for_json(chaine):
    """string_for_json : Supprime tous les caracteres indesirables d'une chaine pour l'integrer au format JSON (quotes, retour chariot, barre oblique )."""
    return chaine.replace('\"', "'").replace('\n', "").replace("\\", "")


def convertirDate(date):
    """convertir Date."""
    return DateTime(date, datefmt='international').strftime("%d/%m/%Y %H:%M")


def convertLangToWIMS(portal_lang):
    """convertLangToWIMS : Converti un code de langue Plone en code de langue WIMS."""
    if portal_lang == "zh-cn":
        # Sur Wims, "cn" doit remplacer le code "zh-cn" de Jalon
        portal_lang = "cn"
    return portal_lang


def encodeUTF8(itemAEncoder):
    """encode itemAEncoder en UTF8."""
    try:
        return [str(encoder).encode("utf-8") for encoder in itemAEncoder]
    except:
        return itemAEncoder


def convertUTF8ToHTMLEntities(source):
    u"""iso-8859-1 ne permet pas d'encoder certains caracteres speciaux comme œ ou €."""
    source = source.replace("€", "&euro;")
    source = source.replace("œ", "&oelig;")
    source = source.replace("’", "&rsquo;")
    return source


def convertHTMLEntitiesToUTF8(source):
    u"""Pour éviter d'avoir des erreur XML 'unrecognized entity', on reconvertit en UTF-8."""
    source = source.replace("&euro;", "€")
    source = source.replace("&oelig;", "œ")
    source = source.replace("&rsquo;", "’")
    return source


def envoyerMail(form):
    u"""envoie un email selon les parametres spécifiés."""
    portal = getUtility(IPloneSiteRoot)
    jalon_properties = getToolByName(portal, "portal_jalon_properties")
    mail_properties = jalon_properties.getPropertiesCourriels()
    if "auteur" in form:
        message = "Message envoyé par %s depuis le cours %s\n\n%s" % (
            form["auteur"], form["cours"], form["message"])
    else:
        message = form["message"]

    if "de" not in form:
        form["de"] = portal.getProperty("email_from_address")
    if "a" not in form:
        if mail_properties["activer_email_erreur"]:
            form["a"] = mail_properties["adresse_email_erreur"]
        else:
            form["a"] = portal.getProperty("email_from_address")

    my_message = message_from_string(message)
    my_message.set_charset('utf-8')
    my_message['Subject'] = Header("[%s] %s" % (portal.Title(), form["objet"]), charset="utf-8")
    my_message['To'] = form["a"]
    my_message['From'] = "Jalon <no-reply@unice.fr>"  # portal.getProperty("email_from_address")
    my_message['Reply-To'] = form["de"]
    my_message['Date'] = email.Utils.formatdate(localtime=True)

    portal.MailHost.send(my_message,
                         mto=form["a"],
                         mfrom="Jalon <no-reply@unice.fr>",
                         subject="[%s] %s" % (portal.Title(), form["objet"]),
                         encode=None, immediate=False, charset='utf8', msg_type="text/html")


def envoyerMailErreur(form):
    # LOG.info("----- envoyerMailErreur -----")
    u"""envoie un email de signalement d'erreur à l'administrateur."""
    portal = getUtility(IPloneSiteRoot)
    jalon_properties = getToolByName(portal, "portal_jalon_properties")
    mail_properties = jalon_properties.getPropertiesCourriels()
    if mail_properties["activer_erreur"]:
        # LOG.info("Mail Erreur actif")
        if "de" not in form:
            if mail_properties["activer_email_erreur"]:
                form["de"] = mail_properties["adresse_email_erreur"]
            else:
                form["de"] = portal.getProperty("email_from_address")
        if "a" not in form:
            if mail_properties["activer_email_erreur"]:
                form["a"] = mail_properties["adresse_email_erreur"]
            else:
                form["a"] = portal.getProperty("email_from_address")

        # LOG.info("De : %s" % form["de"])
        # LOG.info("A  : %s" % form["a"])
        if "entry" in form:
            # error_log = portal.error_log
            # entries = error_log.getLogEntries()

            dico = {}
            entry = portal.error_log.getLogEntryById(form["entry"])
            if not entry:
                text = ""
            else:
                dico['date'] = DateTime(entry['time'])
                dico['username'] = "%s (%s)" % (entry['username'], entry['userid'])
                dico['url'] = entry['url']
                dico['type'] = entry['value']
                dico['value'] = entry['value']

                try:
                    dico['traceback'] = entry['tb_html']
                except:
                    dico['traceback'] = entry['tb_text']
                dico['request'] = entry['req_html']

                text = "\n\n".join(["Traceback", dico['traceback'], "Request", dico['request']])
            if ("__ac" not in text) or ("__accas" not in text):
                text = None
        else:
            text = form["message"]
        if text:
            # Create the enclosing (outer) message
            outer = MIMEMultipart()
            outer['Subject'] = Header(form["objet"], charset="utf-8")
            outer['To'] = form["a"]
            outer['From'] = form["de"]
            outer['Reply-To'] = form["de"]
            outer['Date'] = email.Utils.formatdate(localtime=True)
            outer.preamble = 'You will not see this in a MIME-aware mail reader.\n'
            # To guarantee the message ends with a newline
            outer.epilogue = ''

            # définition du message du mail
            msg = MIMEText(text, 'html', _charset="UTF-8")
            outer.attach(msg)

            # Now send the message
            s = smtplib.SMTP()
            s.connect(portal.MailHost.smtp_host, portal.MailHost.smtp_port)
            if portal.MailHost.smtp_uid:
                s.starttls()
                s.login(portal.MailHost.smtp_uid, portal.MailHost.smtp_pwd)

            s.sendmail(form["de"], form["a"], outer.as_string())

            s.close()


def getJalonProperty(key):
    portal = getUtility(IPloneSiteRoot)
    jalon_properties = getToolByName(portal, "portal_jalon_properties")
    if key.startswith("activer_"):
        return int(jalon_properties.getJalonProperty(key))
    return jalon_properties.getJalonProperty(key)


def flatten(lst):
    """ flatten. """
    for elem in lst:
        if type(elem) in (tuple, list):
            for i in flatten(elem):
                yield i
        else:
            yield elem


def getClefsDico(dico):
    """get Clefs Dico."""
    clefs = dico.keys()
    clefs.sort()
    return clefs


def getIndividu(sesame, type=None, portal=None):
    u"""getIndividu renvoie l'ensemble des infos disponibles (nom, prenom, mail, etc...) pour un sesame (login) en entree.

    # Si l'individu n'existe pas dans la base, il ne sera pas renvoyé.
    # si type="dict", les infos sont retraitées sous forme de dico.

    """
    if portal is None:
        portal = getUtility(IPloneSiteRoot)
    bdd = getToolByName(portal, 'portal_jalon_bdd')
    # retour de  getIndividuLITE :[[IND.LIB_NOM_PAT_IND,
    #                               IND.LIB_PR1_IND,
    #                               IND.SESAME_ETU,
    #                               IND.COD_ETU,
    #                               IND.EMAIL_ETU]]
    individu = bdd.getIndividuLITE(sesame)
    if type == "dict":
        if individu:
            dico = {"sesame":   sesame,
                    "id":       sesame,
                    "nom":      individu["LIB_NOM_PAT_IND"],
                    "prenom":   individu["LIB_PR1_IND"],
                    "fullname": ("%s %s" % (individu["LIB_NOM_PAT_IND"], individu["LIB_PR1_IND"])).encode("utf-8"),
                    "num_etu":  individu["COD_ETU"],
                    "email":    individu["EMAIL_ETU"]}
            return dico
        return {"sesame":   sesame,
                "id":       sesame,
                "nom":      sesame,
                "prenom":   sesame,
                "fullname": sesame,
                "num_etu":  sesame,
                "email":    sesame}

    return individu


def getIndividus(listeSesames, type=None, portal=None):
    u"""
    # getIndividus renvoie l'ensemble des infos disponibles (nom, prenom, mail, etc...) pour la liste des sesames (logins) en entree.

    # Si un individu n'existe pas dans la base, il ne sera pas renvoyé.
    # si type="dict", les infos sont retraitées sous forme de dico.

    """
    if portal is None:
        portal = getUtility(IPloneSiteRoot)
    bdd = getToolByName(portal, 'portal_jalon_bdd')
    # bdd = portal.portal_apogee
    recherche = bdd.getIndividus(listeSesames)
    if not type:
        return recherche
    if type == "dict":
        retour = {}
        for individu in recherche:
            retour[individu[2]] = {"nom":     individu[0],
                                   "prenom":  individu[1],
                                   "num_etu": individu[3],
                                   "email":   individu[4],
                                   "type":    individu[5]}
    if type == "listdict":
        retour = []
        for individu in recherche:
            retour.append({"sesame":  individu[2],
                           "nom":     individu[0],
                           "prenom":  individu[1],
                           "num_etu": individu[3],
                           "email":   individu[4],
                           "type":    individu[5]})
    return retour


def getLocaleDate(date, format="%d/%m/%Y"):
    locale.setlocale(locale.LC_ALL, 'fr_FR')
    return DateTime(date).strftime(format).decode("iso-8859-1")


def getConnectDate(data, sortable=False):
    if not sortable:
        return data.split(' - ')[0].replace('.', '/')
    else:
        dateList = data.replace('h', '').split(' - ')
        return ''.join(dateList[0].split('.')[::-1]) + dateList[1]


def isSameServer(url1, url2):
    u"""Renvoit TRUE si le serveur de l'url "url1" est identique à celui de l'URL "url2"."""
    server1 = urlparse(url1)
    server2 = urlparse(url2)
    return server1.netloc == server2.netloc


def getDepotDate(data, sortable=False):
    if not sortable:
        return data.replace(' -', '')
    else:
        dateList = data.replace('h', '').split(' - ')
        return ''.join(dateList[0].split('/')[::-1]) + dateList[1]


def getPhotoTrombi(login):
    # here.portal_membership.getPersonalPortrait(creator)
    # à mettre en config admin
    req = urllib2.Request(
        "http://camus.unice.fr/unicampus/images/Photos/%sApog0060931E.jpg" % login)
    req.add_header("Expires", "Mon, 26 Jul 1997 05:00:00 GMT")
    req.add_header("Last-Modified", datetime.today())
    req.add_header("Cache-Control", "no-store, no-cache, must-revalidate, post-check=0, pre-check=0")
    req.add_header("Pragma", "no-cache")
    req.add_header("Content-type", "image/jpeg")

    try:
        r = urllib2.urlopen(req)
        return r.read()
    except:
        return None


def getBaseAnnuaire():
    """get Base Annuaire."""
    portal = getUtility(IPloneSiteRoot)
    portal_jalon_properties = getToolByName(portal, 'portal_jalon_properties')
    fiche_ldap = portal_jalon_properties.getPropertiesDonneesUtilisateurs("fiche_ldap")
    # fiche_ldap correspond au champ "Chemin vers une fiche de votre annuaire" des configs Jalon
    if "*-*" in fiche_ldap:
        liste = fiche_ldap.split("*-*")
        if len(liste) > 2:
            return {"base": liste[0],
                    "variable": liste[1],
                    "fin": liste[2]}
        return {"base": liste[0],
                "variable": liste[1],
                "fin": ""}

    return {"base": fiche_ldap,
            "variable": "",
            "fin": ""}


def getFicheAnnuaire(valeur, base=None):
    if not base:
        base = getBaseAnnuaire()
    return "".join([base['base'], valeur[base["variable"]], base["fin"]])

"""
def getInfosMembre(username):
    # Fournit un dico des infos du membre 'username'.
    portal = getUtility(IPloneSiteRoot)
    portal_membership = getToolByName(portal, "portal_membership")
    member = portal_membership.getMemberById(username)
    if member:
        # LOG.info("member ok")
        fullname = member.getProperty("fullname")
        # LOG.info("fullname : %s" % fullname)
        if not fullname:
            fullname = username
        email = member.getProperty("email")
        if not email:
            email = username
    else:
        # LOG.info("not member")
        fullname = email = str(username)
        if isLDAP():
            portal_jalon_properties = getToolByName(portal, 'portal_jalon_properties')
            schema = portal_jalon_properties.getJalonProperty("schema_ldap")
            if schema == "supann":
                ldap = "ldap-plugin"
                member = rechercherUserLDAPSupann(username, "supannAliasLogin", ldap, True)
            if schema == "eduPerson":
                member = rechercherUserLDAPEduPerson(
                    username, "supannAliasLogin", "ldap-plugin", True)
            try:
                fullname = member[0]["name"]
                email = member[0]["email"]
            except:
                pass
    try:
        fullname = fullname.encode('utf-8')
    except:
        pass
    splitted_fullname = fullname.strip().rsplit(" ", 1)
    if len(splitted_fullname) > 1:
        prenom, nom = splitted_fullname
    else:
        prenom = "*UNDEFINED*"
        nom = fullname
    return {"id":       username,
            "fullname": fullname,
            "email":    email,
            "prenom":   prenom,
            "nom":      nom}
"""


def getCourseUserFolder(context, user_id):
    # LOG.info("----- getUserFolder -----")
    portal = context.portal_url.getPortalObject()
    return getattr(portal.cours, user_id)


def rechercherUtilisateur(username, typeUser, match=False, isJson=True):
    u"""recherche des utilisateurs du type 'typeUser' correspondant au critère 'username'."""
    portal = getUtility(IPloneSiteRoot)
    retour = []

    portal_jalon_bdd = getToolByName(portal, "portal_jalon_bdd")
    retour = portal_jalon_bdd.rechercherUtilisateursByName(username, typeUser)

    # Dans le cas ou l'enseignant n'existe pas dans la base de données,
    # on effectue tout de même une recherche LDAP (si possible)
    if len(retour) < 1 and isLDAP() and typeUser == "Personnel":
        portal_jalon_properties = getToolByName(portal, 'portal_jalon_properties')
        schema = portal_jalon_properties.getJalonProperty("schema_ldap")
        if schema == "supann":
            ldap = "ldap-plugin"
            if typeUser == "Etudiant":
                ldap = "ldap-plugin-etu"
            retour = rechercherUserLDAPSupann(username, "displayName", ldap, match)
        if schema == "eduPerson":
            retour = rechercherUserLDAPEduPerson(username, "displayName", "ldap-plugin", match)

    # LOG.info("retour = %s" % retour)

    if isJson:
        return json.dumps(retour)
    return retour


def rechercherUserLDAPSupann(username, attribut, ldap="ldap-plugin", match=False):
    retour = []
    portal = getUtility(IPloneSiteRoot)
    acl_users = getattr(getattr(getattr(portal, "acl_users"), ldap), "acl_users")
    for user in acl_users.findUser(search_param=attribut, search_term=username, exact_match=match):
        if "supannAliasLogin" in user:
            email = user["supannAliasLogin"]
            if "mail" in user:
                email = user["mail"].decode("iso-8859-1")
            retour.append({"id":    user["supannAliasLogin"],
                           "name":  "%s (%s)" % (user["displayName"].decode("iso-8859-1"), user["supannAliasLogin"]),
                           "email": email})
    return retour


def rechercherUserLDAPEduPerson(username, attribut, ldap="ldap-plugin", match=False):
    retour = []
    portal = getUtility(IPloneSiteRoot)
    eduPersonAffiliation = ["employee", "faculty"]
    if ldap == "ldap-plugin-etu":
        eduPersonAffiliation = ["student"]
    acl_users = getattr(getattr(getattr(portal, "acl_users"), ldap), "acl_users")
    for user in acl_users.findUser(search_param=attribut, search_term=username, exact_match=match):
        if "login" in user and user["eduPersonAffiliation"] in eduPersonAffiliation:
            email = user["login"]
            if "mail" in user:
                email = user["mail"].decode("iso-8859-1")
            retour.append({"id":    user["login"],
                           "name":  user["displayName"].decode("iso-8859-1"),
                           "email": email})
    return retour


def getShortText(text, limit=75, suffix=u'…'):
    u"""
        Troncature de texte.

    Remplace les espaces multiples, sauts de ligne, retours chariot et
    tabulations par des espaces.
    Coupe entre les mots avec prise en compte de la ponctuation et des espaces
    insécables.
    Effectue un tronçonnage simple si la partie à conserver de la chaîne ne
    contient aucun espace.

    Args:
        text (str):             le texte a tronquer
        limit (optional[int]):  la longueur maxi souhaitée
        suffix (optional[str]): le caractère à ajouter à la fin

    Returns:
        text (str):             le texte tronqué

    """
    text = re.sub(r'\s+', r' ', text.decode('utf8').strip())
    if len(text) > limit:
        text = text[:limit + 1]
        if text.find(u' ') > -1:
            text = u' '.join(text.split(u' ')[:-1])
            limit = len(text)
        return "".join([text[0:limit].rstrip(u'?!:;.,-" “”«» '), suffix]).encode("utf-8")
    else:
        return text.encode("utf-8")


def getPlainShortText(html, limit=75):
    u"""
        Troncature de contenu HTML.

    Renvoie le retour de getShortText() ci-dessus appliqué au contenu texte brut.

    Args:
        html (str):             le contenu HTML à tronquer
        limit (optional[int]):  la longueur maxi souhaitée

    Returns:
        (str):                  le contenu brut tronqué

    """
    return getShortText(supprimerMarquageHTML(html), limit)


def isLDAP():
    portal = getUtility(IPloneSiteRoot)
    portal_jalon_properties = getToolByName(portal, 'portal_jalon_properties')
    return portal_jalon_properties.getPropertiesDonneesUtilisateurs("activer_ldap")


def setTag(context, tag):
    if tag not in context.Subject():
        tags = list(context.Subject())
        tags.append(tag)
        context.setSubject(tuple(tags))
        context.reindexObject()


def supprimerMarquageHTML(chaine):
    """Suppression marquage HTML."""
    return re.sub('<[^<]+?>', '', chaine)


def remplaceChaine(chaine, elements):
    """Remplacement d'éléments dans une chaîne."""
    for prev, new in elements.iteritems():
        chaine = chaine.replace(prev, new)
    return chaine


def supprimerCaractereSpeciaux(chaine):
    u"""
        "Nettoyage" d'une chaîne de caractères.

    Remplace les caractères accentués par leur équivalent alphanumérique,
    supprime tous les autres caractères non alphanumériques ainsi que les
    tabulations, retours chariot et espaces multiples.

    Args:
        chaine (str):   la chaîne à traiter

    Returns:
        (str):          le résultat du traitement

    """
    accents = { 'a': ['à', 'ã', 'á', 'â', '@', 'ª'],
                'A': ['À', 'Á', 'Â', 'Ä'],
                'AE':['Æ'],
                'ae':['æ'],
                'B': ['ß'],
                'c': ['ç', '¢'],
                'C': ['Ç', '©'],
                'e': ['é', 'è', 'ê', 'ë', '&'],
                'E': ['È', 'É', 'Ê', 'Ë', '€'],
                'i': ['î', 'ï', 'ì', 'í'],
                'I': ['Ì', 'Í', 'Î', 'Ï'],
                'L': ['£'],
                'n': ['ñ'],
                'N': ['Ñ'],
                'o': ['ô', 'ö', 'ò', 'ó', 'ø', 'õ'],
                'O': ['Ò', 'Ó', 'Ô', 'Õ', 'Ö', 'Ø'],
                'oe':['œ'],
                'OE':['Œ'],
                'R': ['®'],
                'u': ['ù', 'ü', 'û', 'µ', 'ú'],
                'U': ['Ù', 'Ú', 'Û', 'Ü'],
                'S': ['$', 'š', 'Š'],
                'x': ['×'],
                'y': ['¥', 'Ý','Ÿ', 'ý', 'ÿ'],
                '_': [' '] }
    chaine = re.sub(r'\s+', r' ', chaine.strip())
    for (char, accentedChars) in accents.iteritems():
        for accentedChar in accentedChars:
            chaine = chaine.replace(accentedChar, char)
    return re.sub('[^\w]', '', chaine)


def test(condition, valeurVrai, valeurFaux):
    return valeurVrai if condition else valeurFaux


def tagFormat(tagSet):
    tagList = tagSet.split(',')
    if 'last' in tagList:
        tagList.remove('last')
    if len(tagList) > 0:
        return ','.join(tagList)
    else:
        return None


def jalon_quote(encode):
    return urllib.quote(encode)


def jalon_unquote(decode):
    """
    Replace %xx escapes by their single-character equivalent.

    Example: unquote('/%7Econnolly/') yields '/~connolly/'.

    """
    return urllib.unquote(decode)


def jalon_urlencode(chaine):
    return urllib.urlencode(chaine)


def isAfficherElement(affElement, masquerElement):
    # LOG.info("***** affElement : %s" % affElement)
    if not affElement:
        return {"val": 0, "icon": "fa-eye-slash", "legende": "Masqué"}
    if cmp(DateTime(), affElement) == -1:
        return {"val": 0, "icon": "fa-calendar-o success", "legende": u"Affichage programmé au %s à %s." % (getLocaleDate(affElement, format="%d/%m/%Y"), getLocaleDate(affElement, format="%Hh%M"))}
    if not masquerElement:
        return {"val": 1, "icon": "", "legende": "Masquage non programmé"}
    if cmp(masquerElement, DateTime()) == -1:
        return {"val": 0, "icon": "fa-eye-slash", "legende": "Date de masquage programmé depassée."}
    return {"val": 1, "icon": "", "icon2": "fa-calendar-o alert", "legende": u"Masquage programmé au %s à %s." % (getLocaleDate(masquerElement, format="%d/%m/%Y"), getLocaleDate(masquerElement, format="%Hh%M"))}


"""
def isAfficherElement(affElement, masquerElement):
    if not affElement:
        return {"val": 0, "icon": "fa-eye-slash", "legende": "masqué"}
    if cmp(DateTime(), affElement) == -1:
        return {"val": 0, "icon": "fa-calendar-o success", "legende": "affichage programmé au %s" % getLocaleDate(affElement, format="%d/%m/%Y à %Hh%M")}
    if not masquerElement:
        return {"val": 1, "icon": "",, "legende": "affiché"}
    if cmp(masquerElement, DateTime()) == -1:
        return {"val": 0, "icon": "fa-eye-slash", "legende": "masquage programmé et depassé"}
    return {"val": 1, "icon": "", "icon2": "fa-calendar-o alert", "legende": "masquage programmé au %s" % getLocaleDate(masquerElement, format="%d/%m/%Y à %Hh%M")}
"""


def retirerEspace(mot):
    motSansEspace = mot.strip()
    motSansEspace = motSansEspace.replace(" ", "")
    motSansEspace = motSansEspace.replace("%20", "")
    return motSansEspace


def getFooter():
    portal = getUtility(IPloneSiteRoot)
    jalon_properties = getToolByName(portal, "portal_jalon_properties")
    dico = copy.copy(jalon_properties.getPropertiesInfos())
    dico["site"] = portal.Title()
    dico["activer_aide"] = jalon_properties.getJalonProperty("activer_aide")
    dico["lien_aide"] = jalon_properties.getJalonProperty("lien_aide")
    return dico


def gaEncodeTexte(chemin, texte):
    return jalon_encode.encodeTexte(chemin, texte)


class MissingExtension(Exception):
    """Exception when the filename has no extension."""


def get_id_from_filename(filename, context):
    from zope import component
    from plone.i18n.normalizer.interfaces import IIDNormalizer
    charset = getattr(context, 'getCharset', None) and context.getCharset()\
        or 'utf-8'
    name = filename.decode(charset).rsplit('.', 1)
    if len(name) != 2:
        raise MissingExtension('It seems like the file extension is missing.')
    normalizer = component.getUtility(IIDNormalizer)
    newid = '.'.join((normalizer.normalize(name[0]), name[1]))
    newid = newid.replace('_', '-').replace(' ', '-').lower()
    return newid



##Python Script "add_course_email_registration_form"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

form = context.REQUEST.form
if form.has_key("invitation"):
    if "," in form["invitation"]:
        email_registration_list = form["invitation"].split(",")
    else:
        email_registration_list = [form["invitation"]]
    context.addEmailRegistration(email_registration_list)

HTTP_X_REQUESTED_WITH = False
if context.REQUEST.HTTP_X_REQUESTED_WITH == 'XMLHttpRequest':
    HTTP_X_REQUESTED_WITH = True

if not HTTP_X_REQUESTED_WITH:
    context.REQUEST.RESPONSE.redirect(context.absolute_url())
else:
    return context.absolute_url()



# -*- coding: utf-8 -*-
# Created relative to Products.Products.PloneboardNotify

from Products.CMFPlone import PloneMessageFactory as _
from Products.CMFCore.utils import getToolByName
from jalon.content.event import html_template

try:
    from email.mime.multipart import MIMEMultipart
    from email.mime.text import MIMEText
except ImportError:
    # py24
    from email.MIMEMultipart import MIMEMultipart
    from email.MIMEText import MIMEText

import re

raw_url_finder = r"""<a.*?class=\"internal-link\".*?href=\"(?P<url1>.*?)\".*?</a>"""
"""|<a.*?href=\"(?P<url2>.*?)\".*?class=\"internal-link\".*?</a>"""
url_finder = re.compile(raw_url_finder)

match_start = "href=\""


def sendMail(object, event):
    conversation = object.getConversation()
    forum = conversation.getForum()
    cours = forum.aq_parent.aq_parent
    if not cours.getActiverEmailForum():
        return None

    portal = getToolByName(object, "portal_url").getPortalObject()
    portal_transforms = getToolByName(object, "portal_transforms")
    portal_membership = getToolByName(object, "portal_membership")
    jalon_bdd = getToolByName(object, "portal_jalon_bdd")

    authMember = portal_membership.getAuthenticatedMember()
    send_from = authMember.getProperty("email")
    if not send_from:
        send_from = portal.getProperty("email_from_address")

    send_to = []
    for acces in cours.getListeAcces():
        code = acces.split("*-*")[1]
        listeEtudiants = jalon_bdd.rechercherUtilisateurs(code, "Etudiant", True)
        for etudiant in listeEtudiants:
            if etudiant["EMAIL_ETU"] and not etudiant["EMAIL_ETU"] in send_to:
                if not etudiant["EMAIL_ETU"] in send_to:
                    send_to.append(etudiant["EMAIL_ETU"])
    for invitation in cours.getInvitations():
        if not invitation in send_to:
            send_to.append(invitation)
    for auteur in cours.getCoAuteursCours():
        if not auteur["email"] in send_to:
            send_to.append(auteur["email"])
    for lecteur in cours.getCourseReader():
        if not lecteur["email"]:
            send_to.append(lecteur["email"])
    if not cours.getAuteur()["email"] in send_to:
        send_to.append(cours.getAuteur()["email"])
    #object.plone_log(send_to)

    translation_service = getToolByName(object, 'translation_service')
    # I use the dummy vars below to make i18ndude works

    dummy = _(u"Nouveau message ajouté dans un forum")
    msg_sbj = u"Nouveau message ajouté dans un forum"
    subject = translation_service.utranslate(domain='jalon.content',
                                             msgid=msg_sbj,
                                             default=msg_sbj,
                                             context=object)
    subject = "[%s]" % portal.Title() + subject
    #object.plone_log(subject)

    dummy = _(u"Message ajouté par : ")
    msg_from = u"Message ajouté par : "
    from_user = translation_service.utranslate(domain='jalon.content',
                                               msgid=msg_from,
                                               default=msg_from,
                                               context=object)
    send_from_fullname = authMember.getProperty("fullname")
    if not send_from_fullname:
        send_from_fullname = authMember.getProperty("displayName")
    from_user += send_from_fullname.decode('utf-8')
    #object.plone_log(from_user)

    dummy = _(u"Nouveau message ajouté dans le forum: ")
    msg_arg_1 = u"Nouveau message ajouté dans le forum: "
    argument = translation_service.utranslate(domain='jalon.content',
                                              msgid=msg_arg_1,
                                              default=msg_arg_1,
                                              context=object)
    argument += forum.Title().decode('utf-8')
    dummy = _(u", pour le cours: ")
    msg_arg_2 = u", pour le cours: "
    argument += translation_service.utranslate(domain='jalon.content',
                                               msgid=msg_arg_2,
                                               default=msg_arg_2,
                                               context=object)
    argument += cours.Title().decode('utf-8')
    #object.plone_log(argument)

    dummy = _(u"Le nouveau message est:")
    msg_txt = u"Le nouveau message est:"
    new_mess = translation_service.utranslate(domain='jalon.content',
                                              msgid=msg_txt,
                                              default=msg_txt,
                                              context=object)
    #object.plone_log(new_mess)

    html_body = object.REQUEST.form['text'].decode('utf-8')
    html_body = html_body.replace("\n", "<br/>")
    #html_body = html_body.replace("\t", "<br/>")
    here_url = object.absolute_url()

    def fixURL(match):
        """Fix relative URL to absolute ones"""
        value = match.group()
        pos_s = value.find(match_start)+len(match_start)
        pos_e = value.find('"', pos_s+1)
        url = value[pos_s:pos_e]
        if not url.startswith(here_url):
            return value.replace(url, "%s/%s" % (here_url, url))
        return value

    html_body = url_finder.sub(fixURL, html_body)

    text = html_template.message % ({'from': from_user,
                                     'argument': argument,
                                     'message_intro': new_mess,
                                     'message': html_body,
                                     'url': here_url,
                                     'url_text': here_url,
                                     })
    #object.plone_log(text)

    text = text.encode("utf-8")
    data_to_plaintext = portal_transforms.convert("html_to_web_intelligent_plain_text", text)
    plain_text = data_to_plaintext.getData()

    for to in send_to:
        #msg = MIMEMultipart()
        msg = MIMEMultipart('alternative')
        # Record the MIME types of both parts - text/plain and text/html.
        part1 = MIMEText(plain_text, 'plain', _charset="utf-8")
        part2 = MIMEText(text, 'html', _charset="utf-8")

        # Attach parts into message container.
        # According to RFC 2046, the last part of a multipart message, in this case
        # the HTML message, is best and preferred.
        msg.attach(part1)
        msg.attach(part2)

        msg['to'] = to
        msg['from'] = "no-reply@unice.fr"
        msg['subject'] = subject
        msg.add_header('reply-to', send_from)

        mail_host = getToolByName(object, 'MailHost')
        #object.plone_log("Message subject: %s" % subject)
        #object.plone_log("Message text:\n%s" % text)
        #object.plone_log("Message sent to %s", to)
        #object.plone_log(msg.as_string().encode("utf-8"))

        try:
            mail_host.send(msg)
        except Exception, inst:
            putils = getToolByName(object, 'plone_utils')
            putils.addPortalMessage(_(u'Not able to send notifications'))
            object.plone_log("Error sending notification: %s" % str(inst))



from plone.i18n.normalizer.interfaces import IIDNormalizer
from Products.CMFCore.utils import getToolByName
from Products.Five import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from zope.component import getMultiAdapter
from zope.component import getUtility

from logging import getLogger
LOG = getLogger('[jalon.content.browser.search]')


class SearchView(BrowserView):
    template = ViewPageTemplateFile("./jalonploneboardsearchview.pt")

    def __init__(self, context, request):
        BrowserView.__init__(self, context, request)

        portal_properties = getToolByName(
            context,
            "portal_properties"
        )
        self.site_properties = portal_properties.site_properties
        plone = getMultiAdapter((self.context, self.request), name="plone")
        self.normalize = getUtility(IIDNormalizer).normalize
        self.icons = plone.icons_visible()
        portal_state = getMultiAdapter(
            (context, request),
            name="plone_portal_state"
        )
        self.portal = portal_state.portal_url() + "/"

    def crop(self, text):
        plone = getMultiAdapter((self.context, self.request), name="plone")
        return plone.cropText(
            text,
            self.site_properties.search_results_description_length,
            self.site_properties.ellipsis
        )

    def update(self):
        LOG.warn("------ update ------")
        if "q" not in self.request.form:
            self.results = []
            return

        text = self.request.form["q"]
        for char in ["(", ")"]:
            text = text.replace(char, '"%s"' % char)

        ct = getToolByName(self.context, "portal_catalog")
        locale_path = "/".join(self.context.getPhysicalPath()).strip()
        LOG.warn(locale_path)
        self.results = ct(
            object_provides="Products.Ploneboard.interfaces.IComment",
            path=locale_path,
            SearchableText=text
        )

    def info(self, brain):
        """Return display-information for a search result.
        """
        obj = brain.getObject()
        conv = obj.getConversation()
        forum = obj.getForum()
        text = obj.getText()

        return dict(
            author=brain.Creator,
            title=brain.Title,
            description=self.crop(text),
            url=brain.getURL() + "/view",
            icon=self.icons and self.portal + brain.getIcon or None,
            forum_url=forum.absolute_url(),
            forum_title=forum.title_or_id(),
            conv_url=conv.absolute_url(),
            conv_title=conv.title_or_id(),
            review_state=self.normalize(brain.review_state),
            portal_type=self.normalize(brain.portal_type),
            relevance=brain.data_record_normalized_score_
        )

    def board_url(self):
        state = getMultiAdapter(
            (self.context, self.request),
            name="plone_context_state"
        )
        return state.view_url()

    def __call__(self):
        self.update()
        return self.template()



## Script (Python) "course_detach_glossary_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

form = context.REQUEST.form

redirection = context.absolute_url()

context.detachGlossaryItem(form["item_id"])

context.REQUEST.RESPONSE.redirect(context.absolute_url())



## Script (Python) "detach_object_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

request = context.REQUEST
if request.has_key("listeCours"):
    idElement = request["ressource"]
    objet = getattr(context, idElement)
    relatedItems = objet.getRelatedItems()

    brains = context.portal_catalog(path={"query": request["listeCours"], "depth": 0})

    for brain in brains:
        parent = brain.getObject()
        relatedItems.remove(parent)
        if "." in idElement:
            idElement = idElement.replace(".", "*-*")
        if parent.portal_type == "JalonCours":
            try:
                if request.form["type"] == "Catalogue BU":
                    parent.tagBU("remove", idElement)
            except:
                pass
            if objet.portal_type == "JalonTermeGlossaire":
                parent.detachGlossaryItem(idElement)
            elif objet.portal_type == "JalonRessourceExterne":
                parent.detachBibliographyItem(idElement)
                parent.deleteCourseMapItem(idElement, None)
            else:
                parent.deleteCourseMapItem(idElement, None)
        else:
            parent.detachDocument(idElement)

    objet.setRelatedItems(relatedItems)
    objet.reindexObject()

if context.REQUEST.HTTP_X_REQUESTED_WITH != 'XMLHttpRequest':
    context.REQUEST.RESPONSE.redirect(context.absolute_url())
else:
    return context.restrictedTraverse(context.getMySpaceFolder())()



# -*- coding: utf-8 -*-
from zope.component import getMultiAdapter
from my_space_view import MySpaceView

from jalon.content import contentMessageFactory as _

from logging import getLogger
LOG = getLogger('[MyFilesView]')


class MyFilesView(MySpaceView):
    """ Class View du fichier my_files_view.pt
    """

    def __init__(self, context, request):
        # LOG.info("----- Init -----")
        MySpaceView.__init__(self, context, request)
        self.context = context
        self.request = request

    def getBreadcrumbs(self):
        return [{"title": _(u"Mes ressources"),
                 "icon":  "fa fa-folder-open",
                 "link":  self.context.aq_parent.absolute_url()},
                {"title": _(u"Mes fichiers"),
                 "icon":  "fa fa-files-o",
                 "link":  self.context.absolute_url()}]

    def getMyFilesView(self, user):
        # LOG.info("----- getMyFilesView -----")
        portal_state = getMultiAdapter((self.context, self.request), name=u'plone_portal_state')
        portal = portal_state.portal()

        folder = getattr(portal.Members, user.getId()).Fichiers
        selected_tags_list = folder.getSelectedTags().split(",")

        tags = self.getTags(folder, selected_tags_list)
        tags_dict = tags["tags_dict"]
        tags_list = tags["tags_list"]

        my_files_list = self.getMyFilesList(folder, selected_tags_list)

        one_and_selected_tag = self.getOneAndSelectedTag(my_files_list, selected_tags_list, tags_dict)

        nb_display_items = len(my_files_list)
        nb_items = len(folder.objectIds())

        return {"tags_list":        tags_list,
                "is_no_items":      one_and_selected_tag["is_no_items"],
                "is_one_tag":       one_and_selected_tag["is_one_tag"],
                "one_tag":          one_and_selected_tag["one_tag"],
                "is_selected_tags": one_and_selected_tag["is_selected_tags"],
                "my_items_list":    my_files_list,
                "nb_display_items": nb_display_items,
                "nb_items":         nb_items,
                "folder_path":      "/".join(folder.getPhysicalPath()),
                "folder_link":      folder.absolute_url()}

    def getMyFilesList(self, folder, selected_tags_list):
        content_filter = {"portal_type": ["File", "Image", "Document"]}
        return self.getItemsList(folder, selected_tags_list, content_filter)



##Python Script "gerer_cours_podcast"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

context.setCoursUser(context.REQUEST.form)
context.REQUEST.RESPONSE.redirect("%s/@@jalon-podcast?message=1" % context.aq_parent.absolute_url())



## Controller Python Script "evaluate_deposit_file_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

form = context.REQUEST.form

context.setEvaluatePeer(form)

redirection = "%s?tab=peers" % context.absolute_url()
if "teacher" in form:
    redirection = "%s/deposit_box_details_evaluations_view" % context.absolute_url()

context.REQUEST.RESPONSE.redirect(redirection)



## Controller Python Script "add_deposit_box_skill_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

param = {}
form = context.REQUEST.form

competences = dict(context.getCompetences())
clefs = competences.keys()
clefs.sort(lambda x, y: cmp(int(x), int(y)))

index = "1"
if competences:
    index = str(int(clefs[-1]) + 1)

competences[index] = {"titre"       : form["title"],
                      "evaluation"  : form["evaluation"],
                      "description" : form["description"]}

if form["evaluation"] == "note":
    competences[index]["note_max"] = form["note_max"]
    competences[index]["note_partielle"] = form["note_partielle"]
    competences[index]["note_acquise"] = form["note_acquise"]

context.setCompetences(competences)

redirection = "%s?tab=skills" % context.absolute_url()

if context.REQUEST.HTTP_X_REQUESTED_WITH != 'XMLHttpRequest':
    context.REQUEST.RESPONSE.redirect(redirection)
else:
    return redirection



## Controller Python Script "edit_peers_correction_number_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=Ajoute un élément ou un sous-element au cours
##

form = context.REQUEST.form

context.setAttributActivite({"NombreCorrection": int(form["nombreCorrection"])})

redirection = "%s?tab=peers" % context.absolute_url()
if context.REQUEST.HTTP_X_REQUESTED_WITH != 'XMLHttpRequest':
    context.REQUEST.RESPONSE.redirect(redirection)
else:
    return redirection


## Controller Python Script "edit_file_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

REQUEST = context.REQUEST
form = REQUEST.form

context.setTitle(form["title"])
context.setDescription(form["description"])

if "image_file" in form:
    context.setImage(form["image_file"])
if "file_file" in form:
    context.setFile(form["file_file"])

context.reindexObject()

context.aq_parent.majFichier(context)

context.REQUEST.RESPONSE.redirect("%s/mes_ressources/mes_fichiers" % context.portal_url.getPortalObject().absolute_url())



##Python Script "delete_course_email_registration_script"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

form = context.REQUEST.form
email_registration_list = []
if form.has_key("etu_email"):
    email_registration_list = form["etu_email"]
context.deleteEmailRegistration(email_registration_list)

context.REQUEST.RESPONSE.redirect(context.absolute_url())